@@ -261,12 +261,25 @@ class Ui_MainWindow(QMainWindow):
         self.gpsButton.show()
         
         dep,arr = self.Selec
-        self.deselec(self.Selec[0])
-        self.deselec(self.Selec[1])
+        self.Selec = '',''
+        #self.deselec(self.Selec[0])
+        #self.deselec(self.Selec[1])
+        #if dep in graph:
+        #    self.setSelec(dep)
+        #if arr in graph:
+        #     self.setSelec(arr)
+        self.panDepart.playX(self.width())
+        self.panAction.playX(self.width())
+        self.panArrivee.playX(self.width())
         if dep in graph:
             self.setSelec(dep)
         if arr in graph:
-             self.setSelec(arr)
+            if self.Selec[0] != '':
+                self.setSelec(arr)
+            else:
+                self.Selec = ('GPS','')
+                self.setSelec(arr)
+                self.deselec('GPS')
 
     def about(self):
         self.stop()
@@ -316,8 +329,7 @@ class Ui_MainWindow(QMainWindow):
                 self.gps.deselec()
                 for item in self.CheminItem:
                     self.scene.removeItem(item)
-                if self.scene.blurred:
-                    self.scene.unblur()
+                self.scene.unblur()
                 self.panDepart.playX(w)
                 self.panArrivee.playX(w)
                 self.panAction.playX(w)
@@ -341,6 +353,8 @@ class Ui_MainWindow(QMainWindow):
                 if self.Selec[1] != '':
                     self.panAction.playX(w,Nom)
             
+            elif self.Selec[0] == Nom and self.Selec[1] == '':
+                return 
         
             else:
                 if self.Selec[0] != Nom and Nom != self.Selec[1]:
@@ -352,6 +366,8 @@ class Ui_MainWindow(QMainWindow):
                 
                     self.panArrivee.playX(w,Nom)
                     self.panAction.playX(w,Nom)
+                    
+
         
     def rectSelec(self,p):
         point = self.view.mapFromScene(p)
@@ -403,10 +419,10 @@ class Ui_MainWindow(QMainWindow):
     def deselec(self,Nom):
         w = self.width()
         h = self.height()
-        if self.scene.blurred:
-            self.scene.unblur()
+        self.scene.unblur()
         for item in self.CheminItem:
             self.scene.removeItem(item)
+        self.CheminItem=[]
         self.Temps.hide()
         
         
